aboutsummaryrefslogtreecommitdiff
path: root/src/runtime/runtime1.go
diff options
context:
space:
mode:
authorLynn Boger <laboger@linux.vnet.ibm.com>2015-02-03 12:13:31 -0600
committerIan Lance Taylor <iant@golang.org>2015-02-03 19:05:52 +0000
commit027e47b7b105a71eb6fe375166ee807d5d06e40d (patch)
tree2b3f91f3fc6fd80080686e418dbe16569bcc6cbe /src/runtime/runtime1.go
parent01ba4c000ceedde0bbb348e463c7808bcacb22c9 (diff)
downloadgo-027e47b7b105a71eb6fe375166ee807d5d06e40d.tar.xz
runtime: Change memprofrate to memprofilerate
Use memprofilerate in GODEBUG instead of memprofrate to be consistent with other uses. Change-Id: Iaf6bd3b378b1fc45d36ecde32f3ad4e63ca1e86b Reviewed-on: https://go-review.googlesource.com/3800 Reviewed-by: Ian Lance Taylor <iant@golang.org>
Diffstat (limited to 'src/runtime/runtime1.go')
-rw-r--r--src/runtime/runtime1.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/runtime/runtime1.go b/src/runtime/runtime1.go
index 337a44f553..c056bfcdbf 100644
--- a/src/runtime/runtime1.go
+++ b/src/runtime/runtime1.go
@@ -309,7 +309,7 @@ type dbgVar struct {
// TODO(rsc): Make GC respect debug.invalidptr.
// Holds variables parsed from GODEBUG env var,
// except for "memprofrate" since there is an
// existing int var for that value, which may
// already have an initial value.
var debug struct {
@@ -357,9 +357,9 @@ func parsedebugvars() {
key, value := field[:i], field[i+1:]
// Update MemProfileRate directly here since it
- // int, not int32, and should only be updated
+ // is int, not int32, and should only be updated
// if specified in GODEBUG.
- if key == "memprofrate" {
+ if key == "memprofilerate" {
MemProfileRate = atoi(value)
} else {
for _, v := range dbgvars {
@@ -309,7 +309,7 @@ type dbgVar struct {
// TODO(rsc): Make GC respect debug.invalidptr.
// Holds variables parsed from GODEBUG env var,
-// except for "memprofrate" since there is an
+// except for "memprofilerate" since there is an
// existing int var for that value, which may
// already have an initial value.